@@ -8,7 +8,7 @@ use vars qw{$VERSION @ISA};
 
 BEGIN
 {
-    $VERSION  = '0.400_010';
+    $VERSION = '0.409_001';
 
     # Load the XS at compile-time so that redefinition warnings will be
     # thrown correctly if the XS versions of part or indexes loaded
@@ -29,12 +29,13 @@ EOLDR
 
     # ensure to catch even PP only subs
     my @pp_imp = map { "List::MoreUtils->can(\"$_\") or *$_ = \\&List::MoreUtils::PP::$_;" }
-	qw(any all none notall any_u all_u none_u notall_u true false
-           firstidx lastidx insert_after insert_after_string
-           apply indexes after after_incl before before_incl
-           firstval lastval each_array each_arrayref pairwise
-	   natatime mesh uniq minmax part bsearch
-	   sort_by nsort_by _XScompiled);
+      qw(any all none notall one any_u all_u none_u notall_u one_u true false
+      firstidx firstval firstres lastidx lastval lastres onlyidx onlyval onlyres
+      insert_after insert_after_string
+      apply after after_incl before before_incl
+      each_array each_arrayref pairwise
+      natatime mesh uniq singleton minmax part indexes bsearch bsearchidx
+      sort_by nsort_by _XScompiled);
     my $pp_stuff = join( "\n", "use List::MoreUtils::PP;", "package List::MoreUtils;", @pp_imp );
     eval $pp_stuff;
     die $@ if $@;
@@ -68,7 +69,8 @@ Tassilo von Parseval E<lt>tassilo.von.parseval@rwth-aachen.deE<gt>
 Some parts copyright 2011 Aaron Crane.
 
 Copyright 2004 - 2010 by Tassilo von Parseval
-Copyright 2013 by Jens Rehsack
+
+Copyright 2013 - 2015 by Jens Rehsack
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.4 or,
